==> haskell-aeson-qq-0.8.4-62-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-qq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 aeson-qq
version:              0.8.4
visibility:           public
id:                   aeson-qq-0.8.4-4omkilPgrk3Or6ZjQk8Bf
key:                  aeson-qq-0.8.4-4omkilPgrk3Or6ZjQk8Bf
license:              MIT
maintainer:           Simon Hengel <sol@typeful.net>
author:               Oscar Finnsson
homepage:             https://github.com/sol/aeson-qq#readme
synopsis:             JSON quasiquoter for Haskell
description:
    @aeson-qq@ provides a JSON quasiquoter for Haskell.

    This package exposes the function `aesonQQ` that compile-time
    converts a string representation of a JSON value into a
    `Data.Aeson.Value`.  `aesonQQ` has the signature

    >aesonQQ :: QuasiQuoter

    Consult the @README@ for documentation:
    <https://github.com/sol/aeson-qq#readme>

category:             JSON
abi:                  1e3fa277af5129f30f85bf2932acff7a
exposed:              True
exposed-modules:      Data.Aeson.QQ
hidden-modules:       Data.JSON.QQ Paths_aeson_qq
import-dirs:          /usr/lib/ghc-9.0.2/site-local/aeson-qq-0.8.4
library-dirs:         /usr/lib/ghc-9.0.2/site-local/aeson-qq-0.8.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson-qq
hs-libraries:         HSaeson-qq-0.8.4-4omkilPgrk3Or6ZjQk8Bf
depends:
    aeson-1.5.6.0-CXf7LknqfgZ2Hfi5jmQpYM
    attoparsec-0.14.4-7GZjDb6SGiTJIjdzxAUMPr base-4.15.1.0
    base-compat-0.12.1-Jgs1a6JPC25AMVxb7dCwve
    haskell-src-meta-0.8.10-6Ih97wC4Jo1I3Mdqln8X2u parsec-3.1.14.0
    scientific-0.3.7.0-8SzWenanV6tE1tEz514SLi template-haskell-2.17.0.0
    text-1.2.5.0 vector-0.12.3.1-50x5zOQFZ1CIL15Y9vpvyM

haddock-interfaces:   /usr/share/doc/haskell-aeson-qq/html/aeson-qq.haddock
haddock-html:         /usr/share/doc/haskell-aeson-qq/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-qq-0.8.4-66-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-qq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 aeson-qq
version:              0.8.4
visibility:           public
id:                   aeson-qq-0.8.4-KZqQrKck5T7Bapa8nYb8ZS
key:                  aeson-qq-0.8.4-KZqQrKck5T7Bapa8nYb8ZS
license:              MIT
maintainer:           Simon Hengel <sol@typeful.net>
author:               Oscar Finnsson
homepage:             https://github.com/sol/aeson-qq#readme
synopsis:             JSON quasiquoter for Haskell
description:
    @aeson-qq@ provides a JSON quasiquoter for Haskell.

    This package exposes the function `aesonQQ` that compile-time
    converts a string representation of a JSON value into a
    `Data.Aeson.Value`.  `aesonQQ` has the signature

    >aesonQQ :: QuasiQuoter

    Consult the @README@ for documentation:
    <https://github.com/sol/aeson-qq#readme>

category:             JSON
abi:                  1b4daba36bd843b5af29c531420a1c25
exposed:              True
exposed-modules:      Data.Aeson.QQ
hidden-modules:       Data.JSON.QQ Paths_aeson_qq
import-dirs:          /usr/lib/ghc-9.0.2/site-local/aeson-qq-0.8.4
library-dirs:         /usr/lib/ghc-9.0.2/site-local/aeson-qq-0.8.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson-qq
hs-libraries:         HSaeson-qq-0.8.4-KZqQrKck5T7Bapa8nYb8ZS
depends:
    aeson-1.5.6.0-2qjjmnAKexuB7sng1Bw4lo
    attoparsec-0.14.4-DMcS99nTm58Eee5UCcw5RC base-4.15.1.0
    base-compat-0.12.1-Jgs1a6JPC25AMVxb7dCwve
    haskell-src-meta-0.8.10-L9u4s97lTkDDqhBvF6tyUE parsec-3.1.14.0
    scientific-0.3.7.0-FYeHmde7xzlEgYl8NcWZ19 template-haskell-2.17.0.0
    text-1.2.5.0 vector-0.12.3.1-IW8bpHdTmVFCpd7YXsgtBR

haddock-interfaces:   /usr/share/doc/haskell-aeson-qq/html/aeson-qq.haddock
haddock-html:         /usr/share/doc/haskell-aeson-qq/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
